Boost logo

Boost-Commit :

Subject: [Boost-commit] svn:boost r52420 - trunk/libs/filesystem/src
From: bdawes_at_[hidden]
Date: 2009-04-16 10:51:57


Author: bemandawes
Date: 2009-04-16 10:51:55 EDT (Thu, 16 Apr 2009)
New Revision: 52420
URL: http://svn.boost.org/trac/boost/changeset/52420

Log:
Workaround: Sun compiler on Linux dirent.h defines _DIRENT_HAVE_D_TYPE but expected macros not present
Text files modified:
   trunk/libs/filesystem/src/operations.cpp | 3 ++-
   1 files changed, 2 insertions(+), 1 deletions(-)

Modified: trunk/libs/filesystem/src/operations.cpp
==============================================================================
--- trunk/libs/filesystem/src/operations.cpp (original)
+++ trunk/libs/filesystem/src/operations.cpp 2009-04-16 10:51:55 EDT (Thu, 16 Apr 2009)
@@ -90,7 +90,8 @@
 //
 // TODO: find out what macros indicate dirent::d_type present in more libraries
 # if defined(BOOST_WINDOWS_API) \
- || defined(_DIRENT_HAVE_D_TYPE) // defined by GNU C library if d_type present
+ || (defined(_DIRENT_HAVE_D_TYPE) /* defined by GNU C library if d_type present */ \
+ && !(defined(__SUNPRO_CC) && !defined(__sun))) // _DIRENT_HAVE_D_TYPE wrong for Sun compiler on Linux
 # define BOOST_FILESYSTEM_STATUS_CACHE
 # endif
 


Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk